  /*
  -----------------Note----------------------
  Date: 02/04/2020
  Project Name: Thief_Detering_Device
  Objective: testing communication
  Author: Khang Nguyen          
*/

#include <SPI.h>
#include <nRF24L01.h>
#include <RF24.h>

int ledState = LOW;  

RF24 radio(9, 10); // CE, CSN

const byte address[6] = "00001";

unsigned long lastReceiveTime = 0;
unsigned long currentTime = 0;

unsigned long previousMillis = 0;  
const long interval = 100;  


struct Data_Package
{
  byte L_Switch;
  byte R_Switch;
  byte Knob_Value;
};

Data_Package data; //Create a variable with the above structure

int LED_RED = 8 ;
 
int LED_Array[4] = {5,4,3,2};


int buzzerPin_R = 7;
int buzzerPin_L = 6;

void setup()
{
  Serial.begin(9600);

  for (int pin = 0; pin <=4 ; pin += 1)
  {
   pinMode((LED_Array[pin]),OUTPUT);
  }
   
  Reciever_Setup();

  resetData();

  Sqe_On(150);
  contact ();

}

void loop()
{
  // Check whether there is data to be received
  if (radio.available())
      {
        radio.read(&data, sizeof(Data_Package)); // Read the whole data and store it into the 'data' structure
       
        lastReceiveTime = millis(); // At this moment we have received the data
   
        Blink_LED(250,50);
         
       }
  // Check whether we keep receving data, or we have a connection between the two modules
  currentTime = millis();
 
  if ( currentTime - lastReceiveTime > 1000 ) // If current time is more then 1 second since we have recived the last data,
  {                                           //that means we have lost connection
      resetData();                            // If connection is lost, reset the data. It prevents unwanted behavior, for example if a drone has a throttle up and we lose connection, it can keep flying unless we reset the values
  }
  if (data.R_Switch == 0){All_On();beep(880,data.Knob_Value);}
  if (data.R_Switch == 1){All_Off();noTone(buzzerPin_R);noTone(buzzerPin_L);}
  if (data.L_Switch == 0){Sqe_On(data.Knob_Value);beep(880,data.Knob_Value);}
  if (data.L_Switch == 1){All_Off();noTone(buzzerPin_R);noTone(buzzerPin_L);}
 
  // Print the data in the Serial Monitor
  Serial.print("L_Switch: ");Serial.println(data.L_Switch );
  Serial.print("R_Switch: ");Serial.println(data.R_Switch );
  Serial.print("Knob Value: ");Serial.println(data.Knob_Value);

  Blink_LED(250,550);
}


//===========LED_Mode==========//
void Blink_LED(int Brightness, int BSpeed)
{
           unsigned long currentMillis = millis();
         if (currentMillis - previousMillis >= BSpeed)
         {
          previousMillis = currentMillis;
         
         if (ledState == 0) {ledState = Brightness;}
         else {ledState = 0;}
   
          analogWrite(LED_RED , ledState);  
         }
}
void All_On()
{
  digitalWrite(LED_Array[0],HIGH);
  digitalWrite(LED_Array[1],HIGH);
  digitalWrite(LED_Array[2],HIGH);
  digitalWrite(LED_Array[3],HIGH);
}
void All_Off()
{
  digitalWrite(LED_Array[0],LOW);
  digitalWrite(LED_Array[1],LOW);
  digitalWrite(LED_Array[2],LOW);
  digitalWrite(LED_Array[3],LOW);
}

void All_Blink(int LED_Speed)
{

  digitalWrite(LED_Array[0],HIGH);
  digitalWrite(LED_Array[1],HIGH);
  digitalWrite(LED_Array[2],HIGH);
  digitalWrite(LED_Array[3],HIGH);
  delay(LED_Speed);
  digitalWrite(LED_Array[0],LOW);
  digitalWrite(LED_Array[1],LOW);
  digitalWrite(LED_Array[2],LOW);
  digitalWrite(LED_Array[3],LOW);
  delay(LED_Speed);
}

void Sqe_On(int LED_Speed)
{
 for (int i = 0 ; i <= 3 ; i+=1)
 {
  digitalWrite(LED_Array[i], HIGH);
  delay(LED_Speed);
 }
 for (int i = 3 ; i >= 0 ; i-=1)
 {
  digitalWrite(LED_Array[i], LOW);
  delay(LED_Speed);
 }
}

void Rand_On( int LED_Speed)
{
  int RandNum = random(0,4);
  digitalWrite(LED_Array[RandNum] , HIGH);
  delay(LED_Speed);
  digitalWrite(LED_Array[RandNum] , LOW);
  delay(LED_Speed);
}
//==============Radio_Setup==================//
void Reciever_Setup()
{
  radio.begin();
  radio.openReadingPipe(0, address);
  radio.setAutoAck(false);
  radio.setDataRate(RF24_250KBPS);
  radio.setPALevel(RF24_PA_LOW);
  radio.startListening(); //  Set the module as receiver
}
//==============Data_Package=================//
void resetData()
{
  data.L_Switch = 1;
  data.R_Switch = 1;
  data.Knob_Value = 0;
}
//==============Buzzer_Function==============//
void beep( int note, int duration)
{
  tone(buzzerPin_R, note, (duration)); //Play tone on buzzerPin
  tone(buzzerPin_L, note, (duration));
  delay(duration);
  noTone(buzzerPin_L);
  noTone(buzzerPin_R);//Stop tone on buzzerPin
  delay(50);
}

void contact ()
{
   for(int i=0;i<20;i++)
  {
  int BSpeed=random(0,200);
  beep(880,BSpeed);
  }
}


void firstSection()
{
 
const int c = 261;const int d = 294;const int e = 329;const int f = 349;
const int g = 391;const int gS = 415;const int a = 440;const int aS = 455;
const int b = 466;const int cH = 523;const int cSH = 554;const int dH = 587;
const int dSH = 622;const int eH = 659;const int fH = 698;
const int fSH = 740;const int gH = 784;const int gSH = 830;const int aH = 880;

  beep(a, 500);beep(a, 500); beep(a, 500);
  beep(f, 350);beep(cH, 150); beep(a, 500);
  beep(f, 350); beep(cH, 150);beep(a, 650);

  delay(500);

  beep(eH, 500);beep(eH, 500);beep(eH, 500);  
  beep(fH, 350);beep(cH, 150);beep(gS, 500);
  beep(f, 350);beep(cH, 150);beep(a, 650);

  delay(500);
}
